import classnames from 'classnames';
import { compact } from 'lodash';

import { PanelBody, ToggleControl } from '@wordpress/components';
import {
	InspectorControls,
	InnerBlocks,
	RichText,
	__experimentalBlock as Block,
} from '@wordpress/block-editor';
import { getBlockTypes } from '@wordpress/blocks';
import { useMemo } from '@wordpress/element';
import { __ } from '@wordpress/i18n';

export default function ( {
	attributes,
	setAttributes,
	isSelected,
	className,
} ) {
	const { label, description, isDisplayLabelColumn } = attributes;

	const ALLOWED_BLOCKS = useMemo( () => {
		const blocks = getBlockTypes();
		const blacklist = [
			'snow-monkey-forms/snow-monkey-form',
			'snow-monkey-forms/item',
		];

		return compact(
			blocks.map( ( block ) => {
				return ! blacklist.includes( block.name ) &&
					( ! block.parent ||
						block.parent.includes( 'snow-monkey-forms/noparent' ) )
					? block.name
					: null;
			} )
		);
	}, [] );

	const BlockWrapper = Block.div;
	const classes = classnames( 'smf-item', className, {
		'smf-item--divider': ! isDisplayLabelColumn,
	} );

	return (
		<>
			<InspectorControls>
				<PanelBody
					title={ __( 'Block settings', 'snow-monkey-forms' ) }
				>
					<ToggleControl
						label={ __(
							'Display label column',
							'snow-monkey-forms'
						) }
						checked={ isDisplayLabelColumn }
						onChange={ ( attribute ) =>
							setAttributes( { isDisplayLabelColumn: attribute } )
						}
					/>
				</PanelBody>
			</InspectorControls>

			<BlockWrapper className={ classes } tabIndex="-1">
				{ isDisplayLabelColumn && (
					<div className="smf-item__col smf-item__col--label">
						<div className="smf-item__label">
							<RichText
								value={ label }
								onChange={ ( value ) =>
									setAttributes( { label: value } )
								}
								placeholder={ __(
									'Label',
									'snow-monkey-forms'
								) }
							/>
						</div>
						{ ( ! RichText.isEmpty( description ) ||
							isSelected ) && (
							<div className="smf-item__description">
								<RichText
									value={ description }
									onChange={ ( value ) =>
										setAttributes( { description: value } )
									}
									placeholder={ __(
										'Description',
										'snow-monkey-forms'
									) }
								/>
							</div>
						) }
					</div>
				) }

				<div className="smf-item__col smf-item__col--controls">
					<div className="smf-item__controls">
						<InnerBlocks
							allowedBlocks={ ALLOWED_BLOCKS }
							templateLock={ false }
							// renderAppender={ () => (
							// 	<InnerBlocks.ButtonBlockAppender />
							// ) }
						/>
					</div>
				</div>
			</BlockWrapper>
		</>
	);
}
